Crate robost_plugin_api

Crate robost_plugin_api 

Structs

FunctionDef
ParamDef
Permissions
PluginInfo
PluginManifest
Manifest read from plugin.toml.

Enums

PluginError
Errors a plugin function may return to the host.
Value
Dynamically-typed value passed between the host and a plugin function.

Type Aliases

PluginResult
Type alias for plugin function results.