Structs
- Function
Def - Param
Def - Permissions
- Plugin
Info - Plugin
Manifest - Manifest read from
plugin.toml.
Enums
- Plugin
Error - Errors a plugin function may return to the host.
- Value
- Dynamically-typed value passed between the host and a plugin function.
Type Aliases
- Plugin
Result - Type alias for plugin function results.